@@ -5,10 +5,12 @@
 # @Email   :  youzyyz1384@qq.com
 # @File    : approve.py
 # @Software: PyCharm
+import os.path
 from typing import Optional
 import aiofiles
 import json
 from nonebot import logger
+from .utils import init
 from pathlib import Path
 
 config_path = Path() / "config"
@@ -31,6 +33,8 @@ async def g_admin():
     """
     :return : 分群管理json对象
     """
+    if not os.path.exists(config_json):
+        await init()
     async with aiofiles.open(config_group, mode='r') as f:
         admins_ = await f.read()
         admins = json.loads(admins_)
@@ -51,9 +55,9 @@ async def g_admin_add(gid: str, qq: int) -> Optional[bool]:
             logger.info(f'{qq}已经是群{gid}的分群管理了')
             return False
         else:
-            g_admins = admins[gid]
-            g_admins.append(qq)
-            admins[gid] = g_admins
+            gadmins = admins[gid]
+            gadmins.append(qq)
+            admins[gid] = gadmins
             async with aiofiles.open(config_group, mode='w') as c:
                 await c.write(str(json.dumps(admins)))
             logger.info(f"群{gid}添加分群管理：{qq}")
